var namespace_v_s_t_g_u_i =
[
    [ "Animation", "namespace_v_s_t_g_u_i_1_1_animation.html", null ],
    [ "BitmapFilter", "namespace_v_s_t_g_u_i_1_1_bitmap_filter.html", "namespace_v_s_t_g_u_i_1_1_bitmap_filter" ],
    [ "Call", "namespace_v_s_t_g_u_i_1_1_call.html", null ],
    [ "CClipboardDetail", "namespace_v_s_t_g_u_i_1_1_c_clipboard_detail.html", "namespace_v_s_t_g_u_i_1_1_c_clipboard_detail" ],
    [ "CDrawMethods", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html", null ],
    [ "Constants", "namespace_v_s_t_g_u_i_1_1_constants.html", null ],
    [ "Detail", "namespace_v_s_t_g_u_i_1_1_detail.html", null ],
    [ "EventPrivate", "namespace_v_s_t_g_u_i_1_1_event_private.html", null ],
    [ "ExternalView", "namespace_v_s_t_g_u_i_1_1_external_view.html", "namespace_v_s_t_g_u_i_1_1_external_view" ],
    [ "PixelBuffer", "namespace_v_s_t_g_u_i_1_1_pixel_buffer.html", "namespace_v_s_t_g_u_i_1_1_pixel_buffer" ],
    [ "Standalone", "namespace_v_s_t_g_u_i_1_1_standalone.html", "namespace_v_s_t_g_u_i_1_1_standalone" ],
    [ "String", "namespace_v_s_t_g_u_i_1_1_string.html", null ],
    [ "UIDescriptionPrivate", "namespace_v_s_t_g_u_i_1_1_u_i_description_private.html", "namespace_v_s_t_g_u_i_1_1_u_i_description_private" ],
    [ "UIViewCreator", "namespace_v_s_t_g_u_i_1_1_u_i_view_creator.html", "namespace_v_s_t_g_u_i_1_1_u_i_view_creator" ],
    [ "VST3EditorInternal", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html", null ],
    [ "Xml", "namespace_v_s_t_g_u_i_1_1_xml.html", "namespace_v_s_t_g_u_i_1_1_xml" ],
    [ "CBitmap", "class_v_s_t_g_u_i_1_1_c_bitmap.html", "class_v_s_t_g_u_i_1_1_c_bitmap" ],
    [ "CNinePartTiledDescription", "struct_v_s_t_g_u_i_1_1_c_nine_part_tiled_description.html", "struct_v_s_t_g_u_i_1_1_c_nine_part_tiled_description" ],
    [ "CButtonState", "struct_v_s_t_g_u_i_1_1_c_button_state.html", "struct_v_s_t_g_u_i_1_1_c_button_state" ],
    [ "CClipboard", "struct_v_s_t_g_u_i_1_1_c_clipboard.html", "struct_v_s_t_g_u_i_1_1_c_clipboard" ],
    [ "CColor", "struct_v_s_t_g_u_i_1_1_c_color.html", "struct_v_s_t_g_u_i_1_1_c_color" ],
    [ "CDrawContext", "class_v_s_t_g_u_i_1_1_c_draw_context.html", "class_v_s_t_g_u_i_1_1_c_draw_context" ],
    [ "ConcatClip", "struct_v_s_t_g_u_i_1_1_concat_clip.html", "struct_v_s_t_g_u_i_1_1_concat_clip" ],
    [ "CDrawMode", "struct_v_s_t_g_u_i_1_1_c_draw_mode.html", "struct_v_s_t_g_u_i_1_1_c_draw_mode" ],
    [ "CExternalViewBaseImpl", "struct_v_s_t_g_u_i_1_1_c_external_view_base_impl.html", "struct_v_s_t_g_u_i_1_1_c_external_view_base_impl" ],
    [ "CExternalView", "class_v_s_t_g_u_i_1_1_c_external_view.html", "class_v_s_t_g_u_i_1_1_c_external_view" ],
    [ "CExternalControl", "class_v_s_t_g_u_i_1_1_c_external_control.html", "class_v_s_t_g_u_i_1_1_c_external_control" ],
    [ "CFileExtension", "class_v_s_t_g_u_i_1_1_c_file_extension.html", "class_v_s_t_g_u_i_1_1_c_file_extension" ],
    [ "CNewFileSelector", "exception_v_s_t_g_u_i_1_1_c_new_file_selector.html", "exception_v_s_t_g_u_i_1_1_c_new_file_selector" ],
    [ "GlobalFonts", "struct_v_s_t_g_u_i_1_1_global_fonts.html", "struct_v_s_t_g_u_i_1_1_global_fonts" ],
    [ "CFontDesc", "class_v_s_t_g_u_i_1_1_c_font_desc.html", "class_v_s_t_g_u_i_1_1_c_font_desc" ],
    [ "ModalViewSession", "struct_v_s_t_g_u_i_1_1_modal_view_session.html", "struct_v_s_t_g_u_i_1_1_modal_view_session" ],
    [ "VSTGUIEditorInterface", "class_v_s_t_g_u_i_1_1_v_s_t_g_u_i_editor_interface.html", "class_v_s_t_g_u_i_1_1_v_s_t_g_u_i_editor_interface" ],
    [ "IMouseObserver", "class_v_s_t_g_u_i_1_1_i_mouse_observer.html", "class_v_s_t_g_u_i_1_1_i_mouse_observer" ],
    [ "OldMouseObserverAdapter", "class_v_s_t_g_u_i_1_1_old_mouse_observer_adapter.html", "class_v_s_t_g_u_i_1_1_old_mouse_observer_adapter" ],
    [ "OldKeyboardHookAdapter", "class_v_s_t_g_u_i_1_1_old_keyboard_hook_adapter.html", "class_v_s_t_g_u_i_1_1_old_keyboard_hook_adapter" ],
    [ "CInvalidRectList", "struct_v_s_t_g_u_i_1_1_c_invalid_rect_list.html", "struct_v_s_t_g_u_i_1_1_c_invalid_rect_list" ],
    [ "CLineStyle", "class_v_s_t_g_u_i_1_1_c_line_style.html", "class_v_s_t_g_u_i_1_1_c_line_style" ],
    [ "COffscreenContext", "class_v_s_t_g_u_i_1_1_c_offscreen_context.html", "class_v_s_t_g_u_i_1_1_c_offscreen_context" ],
    [ "CColorChooserUISettings", "struct_v_s_t_g_u_i_1_1_c_color_chooser_u_i_settings.html", "struct_v_s_t_g_u_i_1_1_c_color_chooser_u_i_settings" ],
    [ "CControl", "class_v_s_t_g_u_i_1_1_c_control.html", "class_v_s_t_g_u_i_1_1_c_control" ],
    [ "IMultiBitmapControl", "class_v_s_t_g_u_i_1_1_i_multi_bitmap_control.html", "class_v_s_t_g_u_i_1_1_i_multi_bitmap_control" ],
    [ "CMouseWheelEditingSupport", "class_v_s_t_g_u_i_1_1_c_mouse_wheel_editing_support.html", "class_v_s_t_g_u_i_1_1_c_mouse_wheel_editing_support" ],
    [ "CKnobBase", "class_v_s_t_g_u_i_1_1_c_knob_base.html", "class_v_s_t_g_u_i_1_1_c_knob_base" ],
    [ "CMenuItem", "class_v_s_t_g_u_i_1_1_c_menu_item.html", "class_v_s_t_g_u_i_1_1_c_menu_item" ],
    [ "IScrollbarDrawer", "class_v_s_t_g_u_i_1_1_i_scrollbar_drawer.html", "class_v_s_t_g_u_i_1_1_i_scrollbar_drawer" ],
    [ "CSliderBase", "class_v_s_t_g_u_i_1_1_c_slider_base.html", "class_v_s_t_g_u_i_1_1_c_slider_base" ],
    [ "CSwitchBase", "class_v_s_t_g_u_i_1_1_c_switch_base.html", "class_v_s_t_g_u_i_1_1_c_switch_base" ],
    [ "CXYPad", "class_v_s_t_g_u_i_1_1_c_x_y_pad.html", "class_v_s_t_g_u_i_1_1_c_x_y_pad" ],
    [ "CommandMenuItemTargetAdapter", "class_v_s_t_g_u_i_1_1_command_menu_item_target_adapter.html", "class_v_s_t_g_u_i_1_1_command_menu_item_target_adapter" ],
    [ "IControlListener", "class_v_s_t_g_u_i_1_1_i_control_listener.html", "class_v_s_t_g_u_i_1_1_i_control_listener" ],
    [ "OptionMenuListenerAdapter", "class_v_s_t_g_u_i_1_1_option_menu_listener_adapter.html", "class_v_s_t_g_u_i_1_1_option_menu_listener_adapter" ],
    [ "TextEditListenerAdapter", "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter.html", "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter" ],
    [ "TextLabelListenerAdapter", "class_v_s_t_g_u_i_1_1_text_label_listener_adapter.html", "class_v_s_t_g_u_i_1_1_text_label_listener_adapter" ],
    [ "CPoint", "struct_v_s_t_g_u_i_1_1_c_point.html", "struct_v_s_t_g_u_i_1_1_c_point" ],
    [ "CRect", "struct_v_s_t_g_u_i_1_1_c_rect.html", "struct_v_s_t_g_u_i_1_1_c_rect" ],
    [ "CResourceDescription", "class_v_s_t_g_u_i_1_1_c_resource_description.html", "class_v_s_t_g_u_i_1_1_c_resource_description" ],
    [ "CAutoLayoutContainerView", "class_v_s_t_g_u_i_1_1_c_auto_layout_container_view.html", "class_v_s_t_g_u_i_1_1_c_auto_layout_container_view" ],
    [ "ISplitViewController", "class_v_s_t_g_u_i_1_1_i_split_view_controller.html", "class_v_s_t_g_u_i_1_1_i_split_view_controller" ],
    [ "ISplitViewSeparatorDrawer", "class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer.html", "class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer" ],
    [ "UTF8CodePointIterator", "class_v_s_t_g_u_i_1_1_u_t_f8_code_point_iterator.html", "class_v_s_t_g_u_i_1_1_u_t_f8_code_point_iterator" ],
    [ "UTF8String", "class_v_s_t_g_u_i_1_1_u_t_f8_string.html", "class_v_s_t_g_u_i_1_1_u_t_f8_string" ],
    [ "TrimOptions", "struct_v_s_t_g_u_i_1_1_trim_options.html", "struct_v_s_t_g_u_i_1_1_trim_options" ],
    [ "UTF8StringView", "class_v_s_t_g_u_i_1_1_u_t_f8_string_view.html", "class_v_s_t_g_u_i_1_1_u_t_f8_string_view" ],
    [ "UTF8CharacterIterator", "class_v_s_t_g_u_i_1_1_u_t_f8_character_iterator.html", "class_v_s_t_g_u_i_1_1_u_t_f8_character_iterator" ],
    [ "CTooltipSupport", "class_v_s_t_g_u_i_1_1_c_tooltip_support.html", "class_v_s_t_g_u_i_1_1_c_tooltip_support" ],
    [ "CViewContainerDropTarget", "struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html", "struct_v_s_t_g_u_i_1_1_c_view_container_drop_target" ],
    [ "GetViewOptions", "struct_v_s_t_g_u_i_1_1_get_view_options.html", "struct_v_s_t_g_u_i_1_1_get_view_options" ],
    [ "CVSTGUITimer", "exception_v_s_t_g_u_i_1_1_c_v_s_t_g_u_i_timer.html", "exception_v_s_t_g_u_i_1_1_c_v_s_t_g_u_i_timer" ],
    [ "DispatchList", "class_v_s_t_g_u_i_1_1_dispatch_list.html", "class_v_s_t_g_u_i_1_1_dispatch_list" ],
    [ "ListenerProvider", "struct_v_s_t_g_u_i_1_1_listener_provider.html", "struct_v_s_t_g_u_i_1_1_listener_provider" ],
    [ "FinalAction", "class_v_s_t_g_u_i_1_1_final_action.html", "class_v_s_t_g_u_i_1_1_final_action" ],
    [ "GenericStringListDataBrowserSourceSelectionChanged", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source_selection_changed.html", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source_selection_changed" ],
    [ "GenericStringListDataBrowserSource", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source.html", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source" ],
    [ "IDataBrowserDelegate", "class_v_s_t_g_u_i_1_1_i_data_browser_delegate.html", "class_v_s_t_g_u_i_1_1_i_data_browser_delegate" ],
    [ "DataBrowserDelegateAdapter", "class_v_s_t_g_u_i_1_1_data_browser_delegate_adapter.html", "class_v_s_t_g_u_i_1_1_data_browser_delegate_adapter" ],
    [ "IDataPackage", "class_v_s_t_g_u_i_1_1_i_data_package.html", "class_v_s_t_g_u_i_1_1_i_data_package" ],
    [ "IScaleFactorChangedListener", "class_v_s_t_g_u_i_1_1_i_scale_factor_changed_listener.html", "class_v_s_t_g_u_i_1_1_i_scale_factor_changed_listener" ],
    [ "IViewListener", "class_v_s_t_g_u_i_1_1_i_view_listener.html", "class_v_s_t_g_u_i_1_1_i_view_listener" ],
    [ "IViewContainerListener", "class_v_s_t_g_u_i_1_1_i_view_container_listener.html", "class_v_s_t_g_u_i_1_1_i_view_container_listener" ],
    [ "ViewListenerAdapter", "class_v_s_t_g_u_i_1_1_view_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_listener_adapter" ],
    [ "ViewEventListenerAdapter", "class_v_s_t_g_u_i_1_1_view_event_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_event_listener_adapter" ],
    [ "ViewContainerListenerAdapter", "class_v_s_t_g_u_i_1_1_view_container_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_container_listener_adapter" ],
    [ "MallocAllocator", "struct_v_s_t_g_u_i_1_1_malloc_allocator.html", "struct_v_s_t_g_u_i_1_1_malloc_allocator" ],
    [ "Buffer", "exception_v_s_t_g_u_i_1_1_buffer.html", "exception_v_s_t_g_u_i_1_1_buffer" ],
    [ "IReference", "class_v_s_t_g_u_i_1_1_i_reference.html", "class_v_s_t_g_u_i_1_1_i_reference" ],
    [ "ReferenceCounted", "class_v_s_t_g_u_i_1_1_reference_counted.html", "class_v_s_t_g_u_i_1_1_reference_counted" ],
    [ "CBaseObject", "class_v_s_t_g_u_i_1_1_c_base_object.html", "class_v_s_t_g_u_i_1_1_c_base_object" ],
    [ "SharedPointer", "class_v_s_t_g_u_i_1_1_shared_pointer.html", "class_v_s_t_g_u_i_1_1_shared_pointer" ],
    [ "CBaseObjectGuard", "class_v_s_t_g_u_i_1_1_c_base_object_guard.html", "class_v_s_t_g_u_i_1_1_c_base_object_guard" ],
    [ "OwningPointer", "class_v_s_t_g_u_i_1_1_owning_pointer.html", "class_v_s_t_g_u_i_1_1_owning_pointer" ],
    [ "BitScopeToggleT", "struct_v_s_t_g_u_i_1_1_bit_scope_toggle_t.html", "struct_v_s_t_g_u_i_1_1_bit_scope_toggle_t" ],
    [ "Base64Codec", "class_v_s_t_g_u_i_1_1_base64_codec.html", "class_v_s_t_g_u_i_1_1_base64_codec" ],
    [ "ZLibInputStream", "class_v_s_t_g_u_i_1_1_z_lib_input_stream.html", "class_v_s_t_g_u_i_1_1_z_lib_input_stream" ],
    [ "ZLibOutputStream", "class_v_s_t_g_u_i_1_1_z_lib_output_stream.html", "class_v_s_t_g_u_i_1_1_z_lib_output_stream" ],
    [ "ZLibInputContentProvider", "class_v_s_t_g_u_i_1_1_z_lib_input_content_provider.html", "class_v_s_t_g_u_i_1_1_z_lib_input_content_provider" ],
    [ "CompressedUIDescription", "class_v_s_t_g_u_i_1_1_compressed_u_i_description.html", "class_v_s_t_g_u_i_1_1_compressed_u_i_description" ],
    [ "OutputStream", "class_v_s_t_g_u_i_1_1_output_stream.html", "class_v_s_t_g_u_i_1_1_output_stream" ],
    [ "InputStream", "class_v_s_t_g_u_i_1_1_input_stream.html", "class_v_s_t_g_u_i_1_1_input_stream" ],
    [ "SeekableStream", "class_v_s_t_g_u_i_1_1_seekable_stream.html", "class_v_s_t_g_u_i_1_1_seekable_stream" ],
    [ "CMemoryStream", "class_v_s_t_g_u_i_1_1_c_memory_stream.html", "class_v_s_t_g_u_i_1_1_c_memory_stream" ],
    [ "CFileStream", "class_v_s_t_g_u_i_1_1_c_file_stream.html", "class_v_s_t_g_u_i_1_1_c_file_stream" ],
    [ "CResourceInputStream", "class_v_s_t_g_u_i_1_1_c_resource_input_stream.html", "class_v_s_t_g_u_i_1_1_c_resource_input_stream" ],
    [ "BufferedOutputStream", "class_v_s_t_g_u_i_1_1_buffered_output_stream.html", "class_v_s_t_g_u_i_1_1_buffered_output_stream" ],
    [ "StdOutStream", "class_v_s_t_g_u_i_1_1_std_out_stream.html", "class_v_s_t_g_u_i_1_1_std_out_stream" ],
    [ "DelegationController", "class_v_s_t_g_u_i_1_1_delegation_controller.html", "class_v_s_t_g_u_i_1_1_delegation_controller" ],
    [ "IContentProvider", "class_v_s_t_g_u_i_1_1_i_content_provider.html", "class_v_s_t_g_u_i_1_1_i_content_provider" ],
    [ "IContextMenuController2", "class_v_s_t_g_u_i_1_1_i_context_menu_controller2.html", "class_v_s_t_g_u_i_1_1_i_context_menu_controller2" ],
    [ "IUIDescription", "class_v_s_t_g_u_i_1_1_i_u_i_description.html", "class_v_s_t_g_u_i_1_1_i_u_i_description" ],
    [ "FocusDrawingSettings", "struct_v_s_t_g_u_i_1_1_focus_drawing_settings.html", "struct_v_s_t_g_u_i_1_1_focus_drawing_settings" ],
    [ "ViewCreatorAdapter", "class_v_s_t_g_u_i_1_1_view_creator_adapter.html", "class_v_s_t_g_u_i_1_1_view_creator_adapter" ],
    [ "IViewFactory", "class_v_s_t_g_u_i_1_1_i_view_factory.html", "class_v_s_t_g_u_i_1_1_i_view_factory" ],
    [ "UIAttributes", "class_v_s_t_g_u_i_1_1_u_i_attributes.html", "class_v_s_t_g_u_i_1_1_u_i_attributes" ],
    [ "MemoryContentProvider", "class_v_s_t_g_u_i_1_1_memory_content_provider.html", "class_v_s_t_g_u_i_1_1_memory_content_provider" ],
    [ "InputStreamContentProvider", "class_v_s_t_g_u_i_1_1_input_stream_content_provider.html", "class_v_s_t_g_u_i_1_1_input_stream_content_provider" ],
    [ "IBitmapCreator", "class_v_s_t_g_u_i_1_1_i_bitmap_creator.html", "class_v_s_t_g_u_i_1_1_i_bitmap_creator" ],
    [ "IBitmapCreator2", "class_v_s_t_g_u_i_1_1_i_bitmap_creator2.html", "class_v_s_t_g_u_i_1_1_i_bitmap_creator2" ],
    [ "UIDescriptionListener", "class_v_s_t_g_u_i_1_1_u_i_description_listener.html", "class_v_s_t_g_u_i_1_1_u_i_description_listener" ],
    [ "UIDescriptionListenerAdapter", "class_v_s_t_g_u_i_1_1_u_i_description_listener_adapter.html", "class_v_s_t_g_u_i_1_1_u_i_description_listener_adapter" ],
    [ "UIDescriptionListenerOff", "struct_v_s_t_g_u_i_1_1_u_i_description_listener_off.html", "struct_v_s_t_g_u_i_1_1_u_i_description_listener_off" ],
    [ "ViewCreatorRegistry", "class_v_s_t_g_u_i_1_1_view_creator_registry.html", "class_v_s_t_g_u_i_1_1_view_creator_registry" ],
    [ "UIViewSwitchContainer", "class_v_s_t_g_u_i_1_1_u_i_view_switch_container.html", "class_v_s_t_g_u_i_1_1_u_i_view_switch_container" ],
    [ "IViewSwitchController", "class_v_s_t_g_u_i_1_1_i_view_switch_controller.html", "class_v_s_t_g_u_i_1_1_i_view_switch_controller" ],
    [ "UIDescriptionViewSwitchController", "class_v_s_t_g_u_i_1_1_u_i_description_view_switch_controller.html", "class_v_s_t_g_u_i_1_1_u_i_description_view_switch_controller" ],
    [ "AEffGUIEditor", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor.html", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor" ],
    [ "ERect", "struct_v_s_t_g_u_i_1_1_e_rect.html", "struct_v_s_t_g_u_i_1_1_e_rect" ],
    [ "ParameterChangeListener", "class_v_s_t_g_u_i_1_1_parameter_change_listener.html", "class_v_s_t_g_u_i_1_1_parameter_change_listener" ],
    [ "VST3EditorDelegate", "class_v_s_t_g_u_i_1_1_v_s_t3_editor_delegate.html", "class_v_s_t_g_u_i_1_1_v_s_t3_editor_delegate" ],
    [ "GroupController", "class_v_s_t_g_u_i_1_1_group_controller.html", "class_v_s_t_g_u_i_1_1_group_controller" ],
    [ "PadController", "class_v_s_t_g_u_i_1_1_pad_controller.html", "class_v_s_t_g_u_i_1_1_pad_controller" ],
    [ "Interface", "class_v_s_t_g_u_i_1_1_interface.html", "class_v_s_t_g_u_i_1_1_interface" ]
];